@@ -1,10 +1,9 @@
 from pathlib import Path
-from typing import Generator, List, Union
+from typing import Generator
 
-from ..utils.string_utils import is_integer
 from ..utils.typeshed import StrPath
-from .row_ref import RowRef
 from .text_base import TextBase
+from .text_file_ref import TextFileRef
 from .text_row import TextRow
 
 
@@ -19,23 +18,11 @@ class TextFileText(TextBase):
 
     def _get_rows(self) -> Generator[TextRow, None, None]:
         with open(self._filename, "r", encoding="utf-8-sig") as file:
-            section_num = 1
-            segment_num = 1
+            line_num = 1
             for line in file:
                 line = line.rstrip("\r\n")
-                if line.lower().startswith("// section"):
-                    section_num_str = line[11:].strip()
-                    if is_integer(section_num_str):
-                        section_num = int(section_num_str)
-                        segment_num = 1
-                else:
-                    keys: List[Union[str, int]] = []
-                    if self.id != "*all*":
-                        keys.append(self.id)
-                    keys.append(section_num)
-                    keys.append(segment_num)
-                    yield self._create_row(line, RowRef(keys))
-                    segment_num += 1
+                yield self._create_row(line, TextFileRef(self.id, line_num))
+                line_num += 1
 
     @property
     def missing_rows_allowed(self) -> bool:
